@@ -1,5 +1,5 @@
 /*
- *  $Id: spss.c,v 1.1.1.1 2001/03/23 16:15:26 bates Exp $
+ *  $Id: spss.c,v 1.3 2001/07/17 12:57:34 ripley Exp $
  *
  *  Read SPSS files saved by SAVE and EXPORT commands
  *
@@ -406,11 +406,13 @@ SEXP
 do_read_SPSS(SEXP file)
 {
     char *filename = CHAR(PROTECT(asChar(file)));
-    FILE *fp = fopen(R_ExpandFileName(filename), "r");
+    FILE *fp = fopen(R_ExpandFileName(filename), "rb");
     char buf[5];
     SEXP ans;
 
-    if (fread_pfm(buf, sizeof(char), 4, fp) != 4) {
+    if(!fp)
+	error("unable to open file");    
+    if(fread_pfm(buf, sizeof(char), 4, fp) != 4) {
 	fclose(fp);
 	error("problem in reading file %s", filename);
     }
